# polyswarm-api

An interface to the PolySwarm Customer APIs.
For an easy-to-use CLI tool, or as an example of how to use these APIs, please see [polyswarm-cli](https://github.com/polyswarm/polyswarm-cli)

Supports Python 2.7 and greater.

## Installation

From PyPI:

    pip install polyswarm-api

From source:

    python3 setup.py install

## Usage

See the [polyswarm-api documentation](https://docs.polyswarm.io/docs/polyswarm-customer-api) for usage guidance.

## API Reference

See the [polyswarm-api reference](https://polyswarm-api.readthedocs.io/en/latest/autoapi/index.html) for API References.

## Questions? Problems?

File a ticket or email us at `info@polyswarm.io`.
